<?php

namespace App\Http\Controllers\API;

use App\Http\Requests\API\CreateSendSmsCmrAPIRequest;
use App\Http\Requests\API\UpdateSendSmsCmrAPIRequest;
use App\Models\SendSmsCmr;
use App\Repositories\SendSmsCmrRepository;
use Illuminate\Http\Request;
use App\Http\Controllers\AppBaseController;
use Response;

/**
 * Class SendSmsCmrController
 * @package App\Http\Controllers\API
 */

class SendSmsCmrAPIController extends AppBaseController
{
    /** @var  SendSmsCmrRepository */
    private $sendSmsCmrRepository;

    public function __construct(SendSmsCmrRepository $sendSmsCmrRepo)
    {
        $this->sendSmsCmrRepository = $sendSmsCmrRepo;
    }

    /**
     * Display a listing of the SendSmsCmr.
     * GET|HEAD /sendSmsCmrs
     *
     * @param Request $request
     * @return Response
     */
    public function index(Request $request)
    {
        $sendSmsCmrs = $this->sendSmsCmrRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        );

        return $this->sendResponse($sendSmsCmrs->toArray(), 'Send Sms Cmrs retrieved successfully');
    }

    /**
     * Store a newly created SendSmsCmr in storage.
     * POST /sendSmsCmrs
     *
     * @param CreateSendSmsCmrAPIRequest $request
     *
     * @return Response
     */
    public function store(CreateSendSmsCmrAPIRequest $request)
    {
        $input = $request->all();

        $sendSmsCmr = $this->sendSmsCmrRepository->create($input);

        return $this->sendResponse($sendSmsCmr->toArray(), 'Send Sms Cmr saved successfully');
    }

    /**
     * Display the specified SendSmsCmr.
     * GET|HEAD /sendSmsCmrs/{id}
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        /** @var SendSmsCmr $sendSmsCmr */
        $sendSmsCmr = $this->sendSmsCmrRepository->find($id);

        if (empty($sendSmsCmr)) {
            return $this->sendError('Send Sms Cmr not found');
        }

        return $this->sendResponse($sendSmsCmr->toArray(), 'Send Sms Cmr retrieved successfully');
    }

    /**
     * Update the specified SendSmsCmr in storage.
     * PUT/PATCH /sendSmsCmrs/{id}
     *
     * @param int $id
     * @param UpdateSendSmsCmrAPIRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateSendSmsCmrAPIRequest $request)
    {
        $input = $request->all();

        /** @var SendSmsCmr $sendSmsCmr */
        $sendSmsCmr = $this->sendSmsCmrRepository->find($id);

        if (empty($sendSmsCmr)) {
            return $this->sendError('Send Sms Cmr not found');
        }

        $sendSmsCmr = $this->sendSmsCmrRepository->update($input, $id);

        return $this->sendResponse($sendSmsCmr->toArray(), 'SendSmsCmr updated successfully');
    }

    /**
     * Remove the specified SendSmsCmr from storage.
     * DELETE /sendSmsCmrs/{id}
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        /** @var SendSmsCmr $sendSmsCmr */
        $sendSmsCmr = $this->sendSmsCmrRepository->find($id);

        if (empty($sendSmsCmr)) {
            return $this->sendError('Send Sms Cmr not found');
        }

        $sendSmsCmr->delete();

        return $this->sendSuccess('Send Sms Cmr deleted successfully');
    }
}
